# gatpack - Notebooks

Here you can find all the notebooks. The naming convention is:

- A number (for ordering),

- The creator's initials or name, and

- A short `_` delimited description, e.g:

  ```
    01_cp_exploratory_data_analysis.ipynb
  ```
